@@ -13,13 +13,14 @@
 #' @param name the name of the set to select
 #' @return the object given as first argument
 #' @examples
-#' upsetjs() %>% fromList(list(a=c(1,2,3), b=c(2,3))) %>% setSelection("b")
-#'
+#' upsetjs() %>%
+#'   fromList(list(a = c(1, 2, 3), b = c(2, 3))) %>%
+#'   setSelection("b")
 #' @export
-setSelection = function(upsetjs, name = NULL) {
+setSelection <- function(upsetjs, name = NULL) {
   checkUpSetCommonArgument(upsetjs)
   stopifnot(is.null(name) ||
-              (is.character(name) && length(name) >= 1))
+    (is.character(name) && length(name) >= 1))
 
   setProperty(upsetjs, "selection", name)
 }
@@ -27,15 +28,16 @@ setSelection = function(upsetjs, name = NULL) {
 #'
 #' make it an interactive chart
 #' @param upsetjs an object of class \code{upsetjs} or \code{upsetjs_proxy}
-#' @param value whether to enable or disable
+#' @param value whether to enable or disable or set the mode: hover, click, contextMenu
 #' @return the object given as first argument
 #' @examples
-#' upsetjs() %>% fromList(list(a=c(1,2,3), b=c(2,3))) %>% interactiveChart()
-#'
+#' upsetjs() %>%
+#'   fromList(list(a = c(1, 2, 3), b = c(2, 3))) %>%
+#'   interactiveChart()
 #' @export
-interactiveChart = function(upsetjs, value = TRUE) {
+interactiveChart <- function(upsetjs, value = TRUE) {
   checkUpSetCommonArgument(upsetjs)
-  stopifnot(is.logical(value), length(value) == 1)
+  stopifnot(is.logical(value) || (value %in% c("hover", "click", "contextMenu")), length(value) == 1)
 
   setProperty(upsetjs, "interactive", value)
 }
